@@ -24,38 +24,31 @@ from mypy_boto3_cloudwatch.paginator import (
     ListMetricsPaginator,
 )
 from mypy_boto3_cloudwatch.type_defs import (
-    ClientDeleteAnomalyDetectorDimensionsTypeDef,
-    ClientDeleteInsightRulesResponseTypeDef,
-    ClientDescribeAlarmHistoryResponseTypeDef,
-    ClientDescribeAlarmsForMetricDimensionsTypeDef,
-    ClientDescribeAlarmsForMetricResponseTypeDef,
-    ClientDescribeAlarmsResponseTypeDef,
-    ClientDescribeAnomalyDetectorsDimensionsTypeDef,
-    ClientDescribeAnomalyDetectorsResponseTypeDef,
-    ClientDescribeInsightRulesResponseTypeDef,
-    ClientDisableInsightRulesResponseTypeDef,
-    ClientEnableInsightRulesResponseTypeDef,
-    ClientGetDashboardResponseTypeDef,
-    ClientGetInsightRuleReportResponseTypeDef,
-    ClientGetMetricDataMetricDataQueriesTypeDef,
-    ClientGetMetricDataResponseTypeDef,
-    ClientGetMetricStatisticsDimensionsTypeDef,
-    ClientGetMetricStatisticsResponseTypeDef,
-    ClientGetMetricWidgetImageResponseTypeDef,
-    ClientListDashboardsResponseTypeDef,
-    ClientListMetricsDimensionsTypeDef,
-    ClientListMetricsResponseTypeDef,
-    ClientListTagsForResourceResponseTypeDef,
-    ClientPutAnomalyDetectorConfigurationTypeDef,
-    ClientPutAnomalyDetectorDimensionsTypeDef,
-    ClientPutDashboardResponseTypeDef,
-    ClientPutMetricAlarmDimensionsTypeDef,
-    ClientPutMetricAlarmMetricsTypeDef,
-    ClientPutMetricAlarmTagsTypeDef,
-    ClientPutMetricDataMetricDataTypeDef,
-    ClientTagResourceTagsTypeDef,
+    AnomalyDetectorConfigurationTypeDef,
+    DeleteInsightRulesOutputTypeDef,
+    DescribeAlarmHistoryOutputTypeDef,
+    DescribeAlarmsForMetricOutputTypeDef,
+    DescribeAlarmsOutputTypeDef,
+    DescribeAnomalyDetectorsOutputTypeDef,
+    DescribeInsightRulesOutputTypeDef,
+    DimensionFilterTypeDef,
+    DimensionTypeDef,
+    DisableInsightRulesOutputTypeDef,
+    EnableInsightRulesOutputTypeDef,
+    GetDashboardOutputTypeDef,
+    GetInsightRuleReportOutputTypeDef,
+    GetMetricDataOutputTypeDef,
+    GetMetricStatisticsOutputTypeDef,
+    GetMetricWidgetImageOutputTypeDef,
+    ListDashboardsOutputTypeDef,
+    ListMetricsOutputTypeDef,
+    ListTagsForResourceOutputTypeDef,
+    MetricDataQueryTypeDef,
+    MetricDatumTypeDef,
+    PutDashboardOutputTypeDef,
+    TagTypeDef,
 )
-from mypy_boto3_cloudwatch.waiter import AlarmExistsWaiter
+from mypy_boto3_cloudwatch.waiter import AlarmExistsWaiter, CompositeAlarmExistsWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -85,66 +78,67 @@ class Exceptions:
 
 class CloudWatchClient:
     """
-    [CloudWatch.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client)
+    [CloudWatch.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
         """
 
     def delete_alarms(self, AlarmNames: List[str]) -> None:
         """
-        [Client.delete_alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
+        [Client.delete_alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
         """
 
     def delete_anomaly_detector(
-        self,
-        Namespace: str,
-        MetricName: str,
-        Stat: str,
-        Dimensions: List[ClientDeleteAnomalyDetectorDimensionsTypeDef] = None,
+        self, Namespace: str, MetricName: str, Stat: str, Dimensions: List[DimensionTypeDef] = None
     ) -> Dict[str, Any]:
         """
-        [Client.delete_anomaly_detector documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
+        [Client.delete_anomaly_detector documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
         """
 
     def delete_dashboards(self, DashboardNames: List[str]) -> Dict[str, Any]:
         """
-        [Client.delete_dashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
+        [Client.delete_dashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
         """
 
-    def delete_insight_rules(self, RuleNames: List[str]) -> ClientDeleteInsightRulesResponseTypeDef:
+    def delete_insight_rules(self, RuleNames: List[str]) -> DeleteInsightRulesOutputTypeDef:
         """
-        [Client.delete_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
+        [Client.delete_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
         """
 
     def describe_alarm_history(
         self,
         AlarmName: str = None,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
         HistoryItemType: Literal["ConfigurationUpdate", "StateUpdate", "Action"] = None,
         StartDate: datetime = None,
         EndDate: datetime = None,
         MaxRecords: int = None,
         NextToken: str = None,
-    ) -> ClientDescribeAlarmHistoryResponseTypeDef:
+        ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
+    ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Client.describe_alarm_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
+        [Client.describe_alarm_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
         """
 
     def describe_alarms(
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
+        ChildrenOfAlarmName: str = None,
+        ParentsOfAlarmName: str = None,
         StateValue: Literal["OK", "ALARM", "INSUFFICIENT_DATA"] = None,
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
-    ) -> ClientDescribeAlarmsResponseTypeDef:
+    ) -> DescribeAlarmsOutputTypeDef:
         """
-        [Client.describe_alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
+        [Client.describe_alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
         """
 
     def describe_alarms_for_metric(
@@ -153,7 +147,7 @@ class CloudWatchClient:
         Namespace: str,
         Statistic: Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"] = None,
         ExtendedStatistic: str = None,
-        Dimensions: List[ClientDescribeAlarmsForMetricDimensionsTypeDef] = None,
+        Dimensions: List[DimensionTypeDef] = None,
         Period: int = None,
         Unit: Literal[
             "Seconds",
@@ -184,9 +178,9 @@ class CloudWatchClient:
             "Count/Second",
             "None",
         ] = None,
-    ) -> ClientDescribeAlarmsForMetricResponseTypeDef:
+    ) -> DescribeAlarmsForMetricOutputTypeDef:
         """
-        [Client.describe_alarms_for_metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
+        [Client.describe_alarms_for_metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
         """
 
     def describe_anomaly_detectors(
@@ -195,39 +189,37 @@ class CloudWatchClient:
         MaxResults: int = None,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List[ClientDescribeAnomalyDetectorsDimensionsTypeDef] = None,
-    ) -> ClientDescribeAnomalyDetectorsResponseTypeDef:
+        Dimensions: List[DimensionTypeDef] = None,
+    ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
-        [Client.describe_anomaly_detectors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
+        [Client.describe_anomaly_detectors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
         """
 
     def describe_insight_rules(
         self, NextToken: str = None, MaxResults: int = None
-    ) -> ClientDescribeInsightRulesResponseTypeDef:
+    ) -> DescribeInsightRulesOutputTypeDef:
         """
-        [Client.describe_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
+        [Client.describe_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
         """
 
     def disable_alarm_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Client.disable_alarm_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
+        [Client.disable_alarm_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
         """
 
-    def disable_insight_rules(
-        self, RuleNames: List[str]
-    ) -> ClientDisableInsightRulesResponseTypeDef:
+    def disable_insight_rules(self, RuleNames: List[str]) -> DisableInsightRulesOutputTypeDef:
         """
-        [Client.disable_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
+        [Client.disable_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
         """
 
     def enable_alarm_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Client.enable_alarm_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
+        [Client.enable_alarm_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
         """
 
-    def enable_insight_rules(self, RuleNames: List[str]) -> ClientEnableInsightRulesResponseTypeDef:
+    def enable_insight_rules(self, RuleNames: List[str]) -> EnableInsightRulesOutputTypeDef:
         """
-        [Client.enable_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
+        [Client.enable_insight_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
         """
 
     def generate_presigned_url(
@@ -236,14 +228,14 @@ class CloudWatchClient:
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
         """
 
-    def get_dashboard(self, DashboardName: str) -> ClientGetDashboardResponseTypeDef:
+    def get_dashboard(self, DashboardName: str) -> GetDashboardOutputTypeDef:
         """
-        [Client.get_dashboard documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
+        [Client.get_dashboard documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
         """
 
     def get_insight_rule_report(
@@ -255,22 +247,22 @@ class CloudWatchClient:
         MaxContributorCount: int = None,
         Metrics: List[str] = None,
         OrderBy: str = None,
-    ) -> ClientGetInsightRuleReportResponseTypeDef:
+    ) -> GetInsightRuleReportOutputTypeDef:
         """
-        [Client.get_insight_rule_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
+        [Client.get_insight_rule_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
         """
 
     def get_metric_data(
         self,
-        MetricDataQueries: List[ClientGetMetricDataMetricDataQueriesTypeDef],
+        MetricDataQueries: List[MetricDataQueryTypeDef],
         StartTime: datetime,
         EndTime: datetime,
         NextToken: str = None,
         ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
         MaxDatapoints: int = None,
-    ) -> ClientGetMetricDataResponseTypeDef:
+    ) -> GetMetricDataOutputTypeDef:
         """
-        [Client.get_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
+        [Client.get_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         """
 
     def get_metric_statistics(
@@ -280,7 +272,7 @@ class CloudWatchClient:
         StartTime: datetime,
         EndTime: datetime,
         Period: int,
-        Dimensions: List[ClientGetMetricStatisticsDimensionsTypeDef] = None,
+        Dimensions: List[DimensionTypeDef] = None,
         Statistics: List[Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"]] = None,
         ExtendedStatistics: List[str] = None,
         Unit: Literal[
@@ -312,39 +304,39 @@ class CloudWatchClient:
             "Count/Second",
             "None",
         ] = None,
-    ) -> ClientGetMetricStatisticsResponseTypeDef:
+    ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Client.get_metric_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
+        [Client.get_metric_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
         """
 
     def get_metric_widget_image(
         self, MetricWidget: str, OutputFormat: str = None
-    ) -> ClientGetMetricWidgetImageResponseTypeDef:
+    ) -> GetMetricWidgetImageOutputTypeDef:
         """
-        [Client.get_metric_widget_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
+        [Client.get_metric_widget_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
         """
 
     def list_dashboards(
         self, DashboardNamePrefix: str = None, NextToken: str = None
-    ) -> ClientListDashboardsResponseTypeDef:
+    ) -> ListDashboardsOutputTypeDef:
         """
-        [Client.list_dashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
+        [Client.list_dashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
         """
 
     def list_metrics(
         self,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List[ClientListMetricsDimensionsTypeDef] = None,
+        Dimensions: List[DimensionFilterTypeDef] = None,
         NextToken: str = None,
-    ) -> ClientListMetricsResponseTypeDef:
+    ) -> ListMetricsOutputTypeDef:
         """
-        [Client.list_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
+        [Client.list_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
         """
 
-    def list_tags_for_resource(self, ResourceARN: str) -> ClientListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(self, ResourceARN: str) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
         """
 
     def put_anomaly_detector(
@@ -352,25 +344,38 @@ class CloudWatchClient:
         Namespace: str,
         MetricName: str,
         Stat: str,
-        Dimensions: List[ClientPutAnomalyDetectorDimensionsTypeDef] = None,
-        Configuration: ClientPutAnomalyDetectorConfigurationTypeDef = None,
+        Dimensions: List[DimensionTypeDef] = None,
+        Configuration: AnomalyDetectorConfigurationTypeDef = None,
     ) -> Dict[str, Any]:
         """
-        [Client.put_anomaly_detector documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
+        [Client.put_anomaly_detector documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
         """
 
-    def put_dashboard(
-        self, DashboardName: str, DashboardBody: str
-    ) -> ClientPutDashboardResponseTypeDef:
+    def put_composite_alarm(
+        self,
+        AlarmName: str,
+        AlarmRule: str,
+        ActionsEnabled: bool = None,
+        AlarmActions: List[str] = None,
+        AlarmDescription: str = None,
+        InsufficientDataActions: List[str] = None,
+        OKActions: List[str] = None,
+        Tags: List[TagTypeDef] = None,
+    ) -> None:
         """
-        [Client.put_dashboard documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
+        [Client.put_composite_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
+        """
+
+    def put_dashboard(self, DashboardName: str, DashboardBody: str) -> PutDashboardOutputTypeDef:
+        """
+        [Client.put_dashboard documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
         """
 
     def put_insight_rule(
         self, RuleName: str, RuleDefinition: str, RuleState: str = None
     ) -> Dict[str, Any]:
         """
-        [Client.put_insight_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
+        [Client.put_insight_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
         """
 
     def put_metric_alarm(
@@ -395,7 +400,7 @@ class CloudWatchClient:
         Namespace: str = None,
         Statistic: Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"] = None,
         ExtendedStatistic: str = None,
-        Dimensions: List[ClientPutMetricAlarmDimensionsTypeDef] = None,
+        Dimensions: List[DimensionTypeDef] = None,
         Period: int = None,
         Unit: Literal[
             "Seconds",
@@ -430,19 +435,17 @@ class CloudWatchClient:
         Threshold: float = None,
         TreatMissingData: str = None,
         EvaluateLowSampleCountPercentile: str = None,
-        Metrics: List[ClientPutMetricAlarmMetricsTypeDef] = None,
-        Tags: List[ClientPutMetricAlarmTagsTypeDef] = None,
+        Metrics: List[MetricDataQueryTypeDef] = None,
+        Tags: List[TagTypeDef] = None,
         ThresholdMetricId: str = None,
     ) -> None:
         """
-        [Client.put_metric_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
+        [Client.put_metric_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
         """
 
-    def put_metric_data(
-        self, Namespace: str, MetricData: List[ClientPutMetricDataMetricDataTypeDef]
-    ) -> None:
+    def put_metric_data(self, Namespace: str, MetricData: List[MetricDatumTypeDef]) -> None:
         """
-        [Client.put_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
+        [Client.put_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
         """
 
     def set_alarm_state(
@@ -453,19 +456,17 @@ class CloudWatchClient:
         StateReasonData: str = None,
     ) -> None:
         """
-        [Client.set_alarm_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
+        [Client.set_alarm_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
         """
 
-    def tag_resource(
-        self, ResourceARN: str, Tags: List[ClientTagResourceTagsTypeDef]
-    ) -> Dict[str, Any]:
+    def tag_resource(self, ResourceARN: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
         """
 
     @overload
@@ -473,35 +474,43 @@ class CloudWatchClient:
         self, operation_name: Literal["describe_alarm_history"]
     ) -> DescribeAlarmHistoryPaginator:
         """
-        [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+        [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_alarms"]) -> DescribeAlarmsPaginator:
         """
-        [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+        [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+        [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_dashboards"]) -> ListDashboardsPaginator:
         """
-        [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+        [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_metrics"]) -> ListMetricsPaginator:
         """
-        [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+        [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["alarm_exists"]) -> AlarmExistsWaiter:
         """
-        [Waiter.AlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        [Waiter.AlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        """
+
+    @overload
+    def get_waiter(
+        self, waiter_name: Literal["composite_alarm_exists"]
+    ) -> CompositeAlarmExistsWaiter:
+        """
+        [Waiter.CompositeAlarmExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
         """
