@@ -23,7 +23,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_cloudwatch.type_defs import (
     DescribeAlarmHistoryOutputTypeDef,
@@ -53,43 +53,48 @@ __all__ = (
 
 class DescribeAlarmHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
     """
 
     def paginate(
         self,
         AlarmName: str = None,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
         HistoryItemType: Literal["ConfigurationUpdate", "StateUpdate", "Action"] = None,
         StartDate: datetime = None,
         EndDate: datetime = None,
+        ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAlarmHistoryOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeAlarmHistoryOutputTypeDef]:
         """
-        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
         """
 
 
 class DescribeAlarmsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
     """
 
     def paginate(
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
+        ChildrenOfAlarmName: str = None,
+        ParentsOfAlarmName: str = None,
         StateValue: Literal["OK", "ALARM", "INSUFFICIENT_DATA"] = None,
         ActionPrefix: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeAlarmsOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeAlarmsOutputTypeDef]:
         """
-        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
         """
 
 
 class GetMetricDataPaginator(Boto3Paginator):
     """
-    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
     """
 
     def paginate(
@@ -99,28 +104,28 @@ class GetMetricDataPaginator(Boto3Paginator):
         EndTime: datetime,
         ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetMetricDataOutputTypeDef, None, None]:
+    ) -> Iterator[GetMetricDataOutputTypeDef]:
         """
-        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
         """
 
 
 class ListDashboardsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
     """
 
     def paginate(
         self, DashboardNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDashboardsOutputTypeDef, None, None]:
+    ) -> Iterator[ListDashboardsOutputTypeDef]:
         """
-        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
         """
 
 
 class ListMetricsPaginator(Boto3Paginator):
     """
-    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
     """
 
     def paginate(
@@ -129,7 +134,7 @@ class ListMetricsPaginator(Boto3Paginator):
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListMetricsOutputTypeDef, None, None]:
+    ) -> Iterator[ListMetricsOutputTypeDef]:
         """
-        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
         """
