@@ -16,7 +16,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, List, TYPE_CHECKING, Type, TypeVar
+from typing import Any, Iterator, List, TYPE_CHECKING, TypeVar
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 from mypy_boto3_cloudwatch.type_defs import (
@@ -51,53 +51,45 @@ _ServiceResourceAlarmsCollectionType = TypeVar(
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     """
 
-    @classmethod
-    def all(
-        cls: Type[_ServiceResourceAlarmsCollectionType],
-    ) -> Type[_ServiceResourceAlarmsCollectionType]:
+    def all(self) -> _ServiceResourceAlarmsCollectionType:
         pass
 
-    @classmethod
     def filter(
-        cls: Type[_ServiceResourceAlarmsCollectionType],
+        self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
+        ChildrenOfAlarmName: str = None,
+        ParentsOfAlarmName: str = None,
         StateValue: Literal["OK", "ALARM", "INSUFFICIENT_DATA"] = None,
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
-    ) -> Type[_ServiceResourceAlarmsCollectionType]:
+    ) -> _ServiceResourceAlarmsCollectionType:
         pass
 
-    @classmethod
-    def delete(cls: Type[_ServiceResourceAlarmsCollectionType]) -> None:
+    def delete(self) -> None:
         pass
 
-    @classmethod
-    def disable_actions(cls: Type[_ServiceResourceAlarmsCollectionType]) -> None:
+    def disable_actions(self) -> None:
         pass
 
-    @classmethod
-    def enable_actions(cls: Type[_ServiceResourceAlarmsCollectionType]) -> None:
+    def enable_actions(self) -> None:
         pass
 
-    @classmethod
-    def limit(
-        cls: Type[_ServiceResourceAlarmsCollectionType], count: int
-    ) -> Type[_ServiceResourceAlarmsCollectionType]:
+    def limit(self, count: int) -> _ServiceResourceAlarmsCollectionType:
         pass
 
-    @classmethod
-    def page_size(
-        cls: Type[_ServiceResourceAlarmsCollectionType], count: int
-    ) -> Type[_ServiceResourceAlarmsCollectionType]:
+    def page_size(self, count: int) -> _ServiceResourceAlarmsCollectionType:
         pass
 
-    @classmethod
-    def pages(cls: Type[_ServiceResourceAlarmsCollectionType]) -> List["Alarm"]:
+    def pages(self) -> Iterator["Alarm"]:
+        pass
+
+    def __iter__(self) -> Iterator["Alarm"]:
         pass
 
 
@@ -108,39 +100,31 @@ _ServiceResourceMetricsCollectionType = TypeVar(
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     """
 
-    @classmethod
-    def all(
-        cls: Type[_ServiceResourceMetricsCollectionType],
-    ) -> Type[_ServiceResourceMetricsCollectionType]:
+    def all(self) -> _ServiceResourceMetricsCollectionType:
         pass
 
-    @classmethod
     def filter(
-        cls: Type[_ServiceResourceMetricsCollectionType],
+        self,
         Namespace: str = None,
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
         NextToken: str = None,
-    ) -> Type[_ServiceResourceMetricsCollectionType]:
+    ) -> _ServiceResourceMetricsCollectionType:
         pass
 
-    @classmethod
-    def limit(
-        cls: Type[_ServiceResourceMetricsCollectionType], count: int
-    ) -> Type[_ServiceResourceMetricsCollectionType]:
+    def limit(self, count: int) -> _ServiceResourceMetricsCollectionType:
         pass
 
-    @classmethod
-    def page_size(
-        cls: Type[_ServiceResourceMetricsCollectionType], count: int
-    ) -> Type[_ServiceResourceMetricsCollectionType]:
+    def page_size(self, count: int) -> _ServiceResourceMetricsCollectionType:
         pass
 
-    @classmethod
-    def pages(cls: Type[_ServiceResourceMetricsCollectionType]) -> List["Metric"]:
+    def pages(self) -> Iterator["Metric"]:
+        pass
+
+    def __iter__(self) -> Iterator["Metric"]:
         pass
 
 
@@ -149,16 +133,14 @@ _MetricAlarmsCollectionType = TypeVar("_MetricAlarmsCollectionType", bound="Metr
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     """
 
-    @classmethod
-    def all(cls: Type[_MetricAlarmsCollectionType]) -> Type[_MetricAlarmsCollectionType]:
+    def all(self) -> _MetricAlarmsCollectionType:
         pass
 
-    @classmethod
     def filter(
-        cls: Type[_MetricAlarmsCollectionType],
+        self,
         Statistic: Literal["SampleCount", "Average", "Sum", "Minimum", "Maximum"] = None,
         ExtendedStatistic: str = None,
         Dimensions: List[DimensionTypeDef] = None,
@@ -192,35 +174,28 @@ class MetricAlarmsCollection(ResourceCollection):
             "Count/Second",
             "None",
         ] = None,
-    ) -> Type[_MetricAlarmsCollectionType]:
+    ) -> _MetricAlarmsCollectionType:
         pass
 
-    @classmethod
-    def delete(cls: Type[_MetricAlarmsCollectionType]) -> None:
+    def delete(self) -> None:
         pass
 
-    @classmethod
-    def disable_actions(cls: Type[_MetricAlarmsCollectionType]) -> None:
+    def disable_actions(self) -> None:
         pass
 
-    @classmethod
-    def enable_actions(cls: Type[_MetricAlarmsCollectionType]) -> None:
+    def enable_actions(self) -> None:
         pass
 
-    @classmethod
-    def limit(
-        cls: Type[_MetricAlarmsCollectionType], count: int
-    ) -> Type[_MetricAlarmsCollectionType]:
+    def limit(self, count: int) -> _MetricAlarmsCollectionType:
         pass
 
-    @classmethod
-    def page_size(
-        cls: Type[_MetricAlarmsCollectionType], count: int
-    ) -> Type[_MetricAlarmsCollectionType]:
+    def page_size(self, count: int) -> _MetricAlarmsCollectionType:
         pass
 
-    @classmethod
-    def pages(cls: Type[_MetricAlarmsCollectionType]) -> List["Alarm"]:
+    def pages(self) -> Iterator["Alarm"]:
+        pass
+
+    def __iter__(self) -> Iterator["Alarm"]:
         pass
 
 
@@ -229,7 +204,7 @@ _AlarmType = TypeVar("_AlarmType", bound="Alarm")
 
 class Alarm(Boto3ServiceResource):
     """
-    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     """
 
     alarm_name: str
@@ -263,44 +238,46 @@ class Alarm(Boto3ServiceResource):
 
     def delete(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         """
 
     def describe_history(
         self,
+        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
         HistoryItemType: Literal["ConfigurationUpdate", "StateUpdate", "Action"] = None,
         StartDate: datetime = None,
         EndDate: datetime = None,
         MaxRecords: int = None,
         NextToken: str = None,
+        ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         """
 
     def disable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         """
 
     def enable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         """
 
     def load(self) -> None:
         """
-        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         """
 
     def reload(self) -> None:
         """
-        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         """
 
     def set_state(
@@ -310,7 +287,7 @@ class Alarm(Boto3ServiceResource):
         StateReasonData: str = None,
     ) -> None:
         """
-        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         """
 
 
@@ -322,7 +299,7 @@ _MetricType = TypeVar("_MetricType", bound="Metric")
 
 class Metric(Boto3ServiceResource):
     """
-    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     """
 
     metric_name: str
@@ -333,7 +310,7 @@ class Metric(Boto3ServiceResource):
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         """
 
     def get_statistics(
@@ -375,12 +352,12 @@ class Metric(Boto3ServiceResource):
         ] = None,
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         """
 
     def load(self) -> None:
         """
-        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         """
 
     def put_alarm(
@@ -443,17 +420,17 @@ class Metric(Boto3ServiceResource):
         ThresholdMetricId: str = None,
     ) -> _Alarm:
         """
-        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         """
 
     def put_data(self, MetricData: List[MetricDatumTypeDef]) -> None:
         """
-        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         """
 
     def reload(self) -> None:
         """
-        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         """
 
 
@@ -462,7 +439,7 @@ _Metric = Metric
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     """
 
     alarms: ServiceResourceAlarmsCollection
@@ -470,15 +447,15 @@ class CloudWatchServiceResource(Boto3ServiceResource):
 
     def Alarm(self, name: str) -> _Alarm:
         """
-        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         """
 
     def Metric(self, namespace: str, name: str) -> _Metric:
         """
-        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.7/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         """
